@@ -104,7 +104,7 @@ class Logger:
             source = f[lenlogsdir+1:].replace('.log','.py')
             try:
                 _df = pd.read_csv(f,header=None,sep=';',\
-                    error_bad_lines=False,engine='python')
+                    error_bad_lines=False,engine='c')
                 _df.columns = ['user','datetime','name','type','message']
                 _df['source'] = source
                 df = df.append(_df)
