@@ -94,11 +94,15 @@ class SharedDataTimeSeries:
             isCreate = self.Malloc(value=value)
 
     def getDataPath(self):        
-        shm_name = self.sharedData.database
+        shm_name = self.sharedData.user
+        shm_name = shm_name + '/' + self.sharedData.database
         shm_name = shm_name + '/' + self.sharedDataFeeder.feeder
         shm_name = shm_name + '/' + self.period + '/' + self.tag
+        shm_name = shm_name.replace('\\','/')
+        
         path = Path(os.environ['DATABASE_FOLDER'])
-        path =  path / shm_name        
+        path = path / shm_name
+        path = Path(str(path).replace('\\','/'))
         if not os.path.isdir(path):
             os.makedirs(path)
         return path, shm_name
